import numpy as np

reveal_type(np.uint128())
reveal_type(np.uint256())

reveal_type(np.int128())
reveal_type(np.int256())

reveal_type(np.float80())
reveal_type(np.float96())
reveal_type(np.float128())
reveal_type(np.float256())

reveal_type(np.complex160())
reveal_type(np.complex192())
reveal_type(np.complex256())
reveal_type(np.complex512())



from typing import List

__all__: List[str]

def sqrt(x): ...
def log(x): ...
def log10(x): ...
def logn(n, x): ...
def log2(x): ...
def power(x, p): ...
def arccos(x): ...
def arcsin(x): ...
def arctanh(x): ...
